@@ -33,9 +33,9 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 /* Still a problem with close_client */
 
-/* Communication interface for external AXIOM buffers */
+/* Communication interface for external FriCAS buffers */
 
-#include "axiom-c-macros.h"
+#include "fricas_c_macros.h"
 #include "debug.h"
 
 #include <signal.h>
@@ -69,7 +69,10 @@ typedef struct sock_list {      /* linked list of Sock */
 Sock_List *plSock = (Sock_List *) 0;
 Sock *spad_socket = (Sock *) 0; /* to_server socket for SpadServer */
 
-/* issue a AXIOM command to the buffer associated with a page */
+char *p2sBuf = NULL;
+int p2sBufSize = 0;
+
+/* issue a FriCAS command to the buffer associated with a page */
 void
 issue_spadcommand(HyperDocPage *page, TextNode *command, int immediate,
                   int type)
@@ -94,8 +97,10 @@ issue_spadcommand(HyperDocPage *page, TextNode *command, int immediate,
     ret_val = send_int(page->sock, ReceiveInputLine);
     buf = print_to_string(command);
     if (immediate) {
-        buf[strlen(buf) + 1] = '\0';
-        buf[strlen(buf)] = '\n';
+        int len = strlen(buf);
+        buf = p2sBuf = resizeBuffer(len + 2, p2sBuf, &p2sBufSize);
+        buf[len + 1] = '\0';
+        buf[len] = '\n';
     }
     if (type == Spadsrc)
         send_pile(page->sock, buf);
@@ -195,33 +200,33 @@ start_user_buffer(HyperDocPage *page)
     if (access(complfile, R_OK) == 0)
 
         /*
-         * TTT says : why not invoke with "-name axiomclient" and set any
+         * TTT says : why not invoke with "-name fricasclient" and set any
          * defaults in the usual way
          */
 #ifdef RIOSplatform
         sprintf(buf,
-                "aixterm -sb -sl 500 -name axiomclient -n '%s' -T '%s'  -e  %s %s %s&",
+                "aixterm -sb -sl 500 -name fricasclient -n '%s' -T '%s'  -e  %s %s %s&",
                 title, title, spadbuf, page->name, complfile);
     else
         sprintf(buf,
-         "aixterm -sb -sl 500 -name axiomclient -n '%s' -T '%s' -e  %s %s&",
+         "aixterm -sb -sl 500 -name fricasclient -n '%s' -T '%s' -e  %s %s&",
                 title, title, spadbuf, page->name);
 #else
 #ifdef SUNplatform
         sprintf(buf,
-        "xterm -sb -sl 500 -name axiomclient -n '%s' -T '%s' -e  %s %s %s&",
+        "xterm -sb -sl 500 -name fricasclient -n '%s' -T '%s' -e  %s %s %s&",
                 title, title, spadbuf, page->name, complfile);
     else
         sprintf(buf,
-           "xterm -sb -sl 500 -name axiomclient -n '%s' -T '%s' -e  %s %s&",
+           "xterm -sb -sl 500 -name fricasclient -n '%s' -T '%s' -e  %s %s&",
                 title, title, spadbuf, page->name);
 #else
         sprintf(buf,
-        "xterm -sb -sl 500 -name axiomclient -n '%s' -T '%s' -e  %s %s %s&",
+        "xterm -sb -sl 500 -name fricasclient -n '%s' -T '%s' -e  %s %s %s&",
                 title, title, spadbuf, page->name, complfile);
     else
         sprintf(buf,
-         "xterm -sb -sl 500 -name axiomclient -n '%s' -T '%s' -e  %s '%s'&",
+         "xterm -sb -sl 500 -name fricasclient -n '%s' -T '%s' -e  %s '%s'&",
                 title, title, spadbuf, page->name);
 #endif
 #endif
@@ -362,9 +367,6 @@ accept_menu_server_connection(HyperDocPage *page)
  * This procedure takes a HyperDoc node, and expands it into string
  */
 
-char *p2sBuf = NULL;
-int p2sBufSize = 0;
-
 /*
  * This routine takes a text node and creates a string out of it. This is for
  * use with things such as spad commands. There are  a very limited set of
@@ -388,7 +390,8 @@ see the code in ht-util.boot
 */
 #define funnyEscape(c)  ((c) == '"' ? '\177' : ((c) == '\\' ? '\200' : c))
 #define funnyUnescape(c) ((c) == '\177' ? '"' : ((c) == '\200' ? '\\' : c))
-#define storeChar(ch) if (sizeBuf) (*sizeBuf)++; else  *c++ = (ch)
+#define storeChar(ch) \
+  do { if (sizeBuf) { (*sizeBuf)++;} else {*c++ = (ch);} } while(0)
 #define storeString(str) for (s=str;*s;s++) {storeChar(*s);}
 
 extern int include_bf;
@@ -636,7 +639,7 @@ print_to_string1(TextNode *command,int * sizeBuf)
 }
 
 /*
- * Send a lisp or spad command to the AXIOM server for execution , if
+ * Send a lisp or spad command to the FriCAS server for execution , if
  * type is link, then we wait for a HyperDoc card to be returned
  */
 
@@ -788,12 +791,12 @@ switch_frames(void)
         fprintf(stderr, "(HyperDoc) No session manager connected!\n");
         return;
     }
-    if (gWindow->fAxiomFrame == -1) {
+    if (gWindow->fricas_frame == -1) {
         fprintf(stderr, "(HyperDoc) No FriCAS frame associated with top level window!\n");
         return;
     }
     send_int(session_server, SwitchFrames);
-    send_int(session_server, gWindow->fAxiomFrame);
+    send_int(session_server, gWindow->fricas_frame);
 }
 void
 send_lisp_command(char *command)
