@@ -74,7 +74,6 @@
 
 ;; These were originally in SPAD LISP
 
-(SETQ $BOOT NIL)
 (setq |$interpOnly| nil)
 (SETQ |$testingSystem| NIL)
 (SETQ |$permitWhere| NIL)
@@ -166,7 +165,6 @@
    (|pquit|                          . |interpreter|)
    (|quit|                           . |interpreter|)
    (|read|                           . |interpreter|)
-   (|savesystem|                     . |interpreter|)
    (|set|                            . |interpreter|)
    (|show|                           . |interpreter|)
    (|spool|                          . |interpreter|)
@@ -211,7 +209,6 @@
     |ltrace|
     |nopiles|
     |read|
-    |savesystem|
     |set|
     |spool|
     |undo|
@@ -261,7 +258,7 @@
        (|time|       . "set message time")
        (|type|       . "set message type")
        (|unexpose|   . "set expose drop constructor")
-       (|version|    . "lisp (concat *build-version* \" compiled at \" *yearweek*)")
+       (|version|    . "lisp (concat |$build_version| \" compiled at \" |$build_date|)")
        (|wc|         . "what categories")
        (|wd|         . "what domains")
        (|wp|         . "what packages")
@@ -491,11 +488,6 @@
 
 ;; ---- end of initial settings for variables used in test.boot
 
-;; Next flag determines whether to use BF as default floating point
-;; type. (actually, now means NewFloat)
-
-; "Determines whether to use BF as default floating point type."
-(SETQ |$useBFasDefault| 'T)
 
 ;; By default, don't generate info files with old compiler.
 (setq |$profileCompiler| nil)
