@@ -49,7 +49,7 @@ at load time.
 ;;; Various lisps use different ``extensions'' on the filename to indicate
 ;;; that a file has been compiled. We set this variable correctly depending
 ;;; on the system we are using.
-(defvar *lisp-bin-filetype*
+(defvar |$lisp_bin_filetype|
   #+:GCL "o"
   #+lucid "bbin"
   #+symbolics "bin"
@@ -65,11 +65,8 @@ at load time.
 ;;; The relative directory list specifies a search path for files
 ;;; for the current directory structure.
 (defvar $relative-directory-list
-  '("/../../src/input/"
-    "/doc/msgs/"
-    "/../../src/algebra/"
-    "/../../src/interp/"  ; for boot and lisp  files (helps fd)
-    "/doc/spadhelp/" ))
+  '("/share/msgs/"
+    "/share/spadhelp/" ))
 
 ;;; The relative directory list specifies how to find the algebra
 ;;; directory from the current {\bf AXIOM} shell variable.
@@ -83,16 +80,17 @@ at load time.
 ;;; It is set up in the {\bf reroot} function.
 (defvar $library-directory-list ())
 
-;;; This is the {\bf boot parser} subsystem. It is only needed by
-;;; algebra developers and developers who translate boot code to
-;;; Common Lisp.
+;;; This is the {\bf Spad parser} subsystem. It is only needed by
+;;; algebra developers.  Currently included in base system.
+#|
 (setq parse-functions
       '(
 ;;      loadparser
         |oldParserAutoloadOnceTrigger|
         |parse_Expression|
         |spadCompile|
-        init-boot/spad-reader))
+        ))
+|#
 
 ;;; This is the {\bf spad compiler} subsystem. It is only needed by
 ;;; developers who write or modify algebra code.
@@ -158,7 +156,6 @@ at load time.
         |htSystemCommands|
         |htSystemVariables|
         |htTextSearch|
-        |htTutorialSearch|
         |htUserVariables|
         |htsv|
         |oPage|
@@ -229,8 +226,8 @@ This helper function is listed below.
 ;;; files.
 (defun boot-load (file)
   (let ((name (concat $SPADROOT "/autoload/" (pathname-name file))))
-    (if (eq |$printLoadMsgs| '|on|)
-	(|sayKeyedMsg| 'S2IL0030 (list name)))
+    (if |$printLoadMsgs|
+        (|sayKeyedMsg| 'S2IL0030 (list name)))
     (load name)))
 
 ;;; This is a helper function to set up the autoload trigger. It sets
@@ -390,8 +387,7 @@ After this function is called the image is clean and can be saved.
           (c:build-fasl (concatenate 'string spad "/autoload/" (car el))
                         :lisp-files (nth 1 el)))
       (let ((initforms nil))
-          (dolist (el '(*YEARWEEK* *BUILD-VERSION* timestamp
-                    |$createLocalLibDb|))
+          (dolist (el '(|$build_date| |$build_version| |$createLocalLibDb|))
               (if (boundp el)
                   (push (list 'defparameter el (symbol-value el))
                         initforms)))
@@ -410,7 +406,7 @@ After this function is called the image is clean and can be saved.
                  (if (and sym (fboundp sym))
                      (funcall sym T T)))
      #+:ecl (let ((sym (find-symbol "*BREAK-ENABLE*" "SI")))
-                (if (and sym (boundp sym)) 
+                (if (and sym (boundp sym))
                     (setf (symbol-value sym) t)))
      (initroot spad)
      (setf spad $spadroot)
@@ -448,39 +444,6 @@ After this function is called the image is clean and can be saved.
 ;; the following are for conditional reading
 (setq |$opSysName| '"shell")
 
-#|
-We need a way of distinguishing different versions of the system.
-There used to be a way to touch the src/timestamp file whenever
-you checked in a change to the change control subsystem.
-During make PART=interp (the default for make) we set timestamp
-to the filename of this timestamp file. This function converts it
-to a luser readable string and sets the *yearweek* variable.
-
-The result of this function is a string that is printed as a banner
-when Axiom starts. The actual printing is done by the function
-[[spadStartUpMsgs]] in [[src/interp/msgdb.boot]]. It uses a
-format string from the file [[src/doc/msgs/s2-us.msgs]].
-|#
-(defun yearweek ()
- "set *yearweek* to the current time string for the version banner"
-  (declare (special timestamp) (special *yearweek*))
-  (if (and (boundp 'timestamp) (probe-file timestamp))
-      (let (sec min hour date month year day dayvec monvec)
-        (setq dayvec '("Monday" "Tuesday" "Wednesday" "Thursday"
-                       "Friday" "Saturday" "Sunday"))
-        (setq monvec '("January" "February" "March" "April" "May" "June"
-                       "July" "August" "September" "October" "November"
-                       "December"))
-        (multiple-value-setq (sec min hour date month year day)
-                             (decode-universal-time
-                              (file-write-date timestamp)))
-        (setq *yearweek*
-          (copy-seq
-              (format nil "~a ~a ~d, ~d at ~2,'0d:~2,'0d:~2,'0d "
-                      (elt dayvec day)
-                      (elt monvec (1- month)) date year hour min sec))))
-      (setq *yearweek* "no timestamp")))
-
 ;;; moved from bookvol5
 
 (defvar |$HiFiAccess| t               "t means turn on history mechanism")
@@ -520,14 +483,14 @@ format string from the file [[src/doc/msgs/s2-us.msgs]].
             (format t "Checking for foreign routines~%")
             (format t "AXIOM=~S~%" ax-dir)
             (format t "spad-lib=~S~%" spad-lib)
-            (if (fricas-probe-file spad-lib)
+            (if (|fricas_probe_file| spad-lib)
                 (progn
                     (setf *fricas-load-libspad* nil)
                     (format t "foreign routines found~%")
                     #+(or :sbcl :openmcl :lispworks)
                     (|quiet_load_alien| spad-lib)
                     #+(or :sbcl :openmcl)
-                    (fricas-lisp::init-gmp 
+                    (fricas-lisp::init-gmp
                         (concatenate 'string ax-dir "/lib/gmp_wrap.so"))
                     #+(and :clisp :ffi)
                     (progn
@@ -549,7 +512,14 @@ format string from the file [[src/doc/msgs/s2-us.msgs]].
   (|interpsys_restart|)
 )
 
+(DEFVAR |$trace_stream| *standard-output*)
+(DEFVAR CUROUTSTREAM *standard-output*)
+
 (defun fricas-restart ()
+  ;;; Need to reinitialize CUROUTSTREAM and |$trace_stream| because
+  ;;;  clisp closes it when dumping executable
+  (setf CUROUTSTREAM *standard-output*)
+  (setf |$trace_stream| *standard-output*)
   (fricas-init)
   #+(or :GCL :poplog)
   (|spad|)
@@ -593,6 +563,9 @@ format string from the file [[src/doc/msgs/s2-us.msgs]].
     (eval  x)
 )
 
+;;; For evaluating categories we need to bind $.
+(defun |c_eval|(u) (let (($ '$)) (declare (special $)) (|eval| u)))
+
 ;;; Accesed from HyperDoc
 (defun |setViewportProcess| ()
   (setq |$ViewportProcessToWatch|
@@ -653,6 +626,3 @@ format string from the file [[src/doc/msgs/s2-us.msgs]].
 ;; (|xdrRead| xfoo 0.0)
 ;; (|xdrRead| xfoo (make-array 10 :element-type 'double-float ))
 ;; (setq *print-array* NIL)
-
-(setq /MAJOR-VERSION 2)
-(defun /versioncheck (n) (unless (= n /MAJOR-VERSION) (throw 'versioncheck -1)))
