@@ -45,12 +45,6 @@
 
 (in-package "BOOT")
 
-;; DEFVARS
-
-(defvar CUROUTSTREAM *standard-output*)
-
-(defvar *fileactq-apply* nil "function to apply in fileactq")
-
 ;; defuns
 
 (defun define-function (f v)
@@ -62,8 +56,7 @@
 ;;; Used in constructors for evaluating conditions
 (define-function '|not| #'NOT)
 
-
-(define-function 'tempus-fugit #'get-internal-run-time)
+(define-function '|get_run_time| #'get-internal-run-time)
 
 ; 9.4 Vectors and Bpis
 
@@ -165,7 +158,7 @@
 ; 14.1 Creation
 
 ;;; needed for SPAD compiler output
-(define-function '|construct| #'list) 
+(define-function '|construct| #'list)
 
 (defun VEC2LIST (vec) (coerce vec 'list))
 
@@ -298,10 +291,6 @@
 
 ; 14.6 Miscellaneous
 
-(defun QSORT (l)
- (declare (special sortgreaterp))
-  (NREVERSE (sort (copy-seq l) SORTGREATERP)))
-
 (defun SORTBY (keyfn l)
  (declare (special sortgreaterp))
   (nreverse (sort (copy-seq l) SORTGREATERP :key keyfn)))
@@ -358,7 +347,7 @@
 (define-function '|isLowerCaseLetter| #'LOWER-CASE-P)
 
 #+(or :UNICODE :SB-UNICODE :OPENMCL-UNICODE-STRINGS)
-(defun NUM2USTR (n) 
+(defun NUM2USTR (n)
     (make-string 1 :initial-element (NUM2CHAR n)))
 #-(or :UNICODE :SB-UNICODE :OPENMCL-UNICODE-STRINGS)
 (defun NUM2USTR (n)
@@ -391,7 +380,68 @@
        (make-array k :element-type 'character
                   :initial-contents (mapcar #'code-char l))))
 
-(defun CGREATERP (s1 s2) (string> (string s1) (string s2)))
+
+(defun UENTRIES(s)
+   (let* ((res (cons nil nil))
+         (res1 res)
+         (c 0)
+         (i 0)
+         (l (length s)))
+        (loop
+        (cond ((eql i l) (return-from UENTRIES (cdr res))))
+#+(or :UNICODE :SB-UNICODE :OPENMCL-UNICODE-STRINGS)
+        (progn
+            (setf c (char-code (aref s i)))
+            (setf i (+ i 1)))
+#-(or :UNICODE :SB-UNICODE :OPENMCL-UNICODE-STRINGS)
+        (let ((c1 (char-code (aref s i))))
+            (cond ((< c1 128)
+                   (setf c c1)
+                   (setf i (+ i 1)))
+                  ((< c1 224)
+                      (cond ((> (+ i 2) l)
+                             (|error| "Invalid UTF-8 string"))
+                            (t
+                              (setf c (logior
+                                          (logand 63
+                                                 (char-code (aref s (+ i 1))))
+                                          (ash (logand 31 c1) 6)))
+                              (setf i (+ i 2)))))
+                  ((< c1 240)
+                      (cond ((> (+ i 3) l)
+                             (|error| "Invalid UTF-8 string"))
+                            (t
+                              (setf c (logior
+                                          (logand 63
+                                                 (char-code (aref s (+ i 2))))
+                                          (ash (logand 63
+                                                 (char-code (aref s (+ i 1))))
+                                               6)
+                                          (ash (logand 15 c1) 12)))
+                              (setf i (+ i 3)))))
+                  ((< c1 248)
+                      (cond ((> (+ i 4) l)
+                             (|error| "Invalid UTF-8 string"))
+                            (t
+                              (setf c (logior
+                                          (logand 63
+                                                 (char-code (aref s (+ i 3))))
+                                          (ash (logand 63
+                                                 (char-code (aref s (+ i 2))))
+                                               6)
+                                          (ash (logand 63
+                                                 (char-code (aref s (+ i 1))))
+                                               12)
+                                          (ash (logand 7 c1) 18)))
+                              (cond ((>= c 1114112)
+                                     (|error| "Invalid UTF-8 string")))
+                              (setf i (+ i 4)))))
+                  (t (|error| "Invalid UTF-8 string"))))
+        (setf (cdr res1) (cons c nil))
+        (setf res1 (cdr res1)))))
+
+;;; Double negation to have boolean result
+(defun CGREATERP (s1 s2) (not (not (string> (string s1) (string s2)))))
 
 ; 17.1 Creation
 
@@ -414,9 +464,6 @@
 
 (define-function 'strconc #'concat)
 
-(defun |make_CVEC| (sint)
-    (make-array sint :fill-pointer 0 :element-type 'character))
-
 (defun |make_full_CVEC|(sint &optional (char #\space))
   (make-string sint :initial-element (if (integerp char)
                                        (code-char char)
@@ -424,12 +471,6 @@
 
 ; 17.2 Accessing
 
-(defun QENUM (cvec ind) (char-code (char cvec ind)))
-
-(defun QESET (cvec ind charnum)
-  (setf (char cvec ind) (code-char charnum))
-  charnum)
-
 (defun string2id-n (cvec sint)
   (if (< sint 1)
       nil
@@ -447,14 +488,6 @@
 
 ; 17.3 Searching
 
-;;- (defun strpos (what in start dontcare)
-;;-    (setq what (string what) in (string in))
-;;-    (if dontcare (progn (setq dontcare (character dontcare))
-;;-                    (search what in :start2 start
-;;-                            :test #'(lambda (x y) (or (eql x dontcare)
-;;-                                                      (eql x y)))))
-;;-                 (search what in :start2 start)))
-
 (defun strpos (what in start dontcare)
    (setq what (string what) in (string in))
    (if dontcare (progn (setq dontcare (character dontcare))
@@ -476,20 +509,6 @@
 
 ; 17.4 Updating operators
 
-(defun SUFFIX(id cvec)
-  "Suffixes the first char of the symbol or char ID to the string CVEC,
-    changing CVEC."
-  (unless (characterp id) (setq id (elt (string id) 0)))
-  (cond ((array-has-fill-pointer-p cvec)
-         (vector-push-extend id cvec)
-         cvec)
-        ((adjustable-array-p cvec)
-         (let ((l (length cvec)))
-           (adjust-array cvec (1+ l))
-           (setf (elt cvec l) id)
-           cvec))
-        (t (concat cvec id))))
-
 ;;-- (defun rplacstr (cvec1 start1 length1 cvec2
 ;;--                        &optional (start2 0) (length2 nil)
 ;;--                        &aux end1 end2)
@@ -570,10 +589,11 @@
 (define-function 'printexp #'princ)
 (define-function 'prin0  #'prin1)
 
-(defun |F,PRINT-ONE| (form &optional (stream *standard-output*))
- (declare (ignore stream))
+(defun |limited_print1_stdout|(form) (|limited_print1| form *standard-output*))
+
+(defun |limited_print1|(form stream)
     (let ((*print-level* 4) (*print-length* 4))
-       (prin1 form) (terpri)))
+       (prin1 form stream) (terpri stream)))
 
 (defun prettyprint (x &optional (stream *standard-output*))
   (prettyprin0 x stream) (terpri stream))
@@ -622,100 +642,6 @@
 
 (defun EOFP (stream) (null (peek-char nil stream nil nil)))
 
-
-; 46.0 Call tracing
-
-(defvar *embedded-functions* nil)
-
-(defun EMBEDDED () (mapcar #'car *embedded-functions*))
-
-(defun EMBED (CURRENT-BINDING NEW-DEFINITION)
-  (PROG
-      (OP BV BODY OLD-DEF)
-      (COND
-        ( (NOT (IDENTP CURRENT-BINDING))
-            (error (format nil "invalid argument ~s to EMBED"
-                      CURRENT-BINDING))) )
-      (SETQ OLD-DEF (symbol-function CURRENT-BINDING))
-      (SETQ NEW-DEFINITION
-          (COND
-            ( (NOT (consp NEW-DEFINITION))
-              NEW-DEFINITION )
-            ( (AND
-		(setf BODY (ifcdr (ifcdr NEW-DEFINITION)))
-		(or (progn (setf OP (car NEW-DEFINITION))
-		           (setf BV (car (cdr NEW-DEFINITION))))
-		    T)
-                (OR (EQ OP 'LAMBDA) (EQ OP 'MLAMBDA)))
-              (COND
-                ( (NOT (MEMQ CURRENT-BINDING (FLAT-BV-LIST BV)))
-                 `(,OP ,BV ((LAMBDA (,CURRENT-BINDING) . ,BODY) ',OLD-DEF))
-                   )
-                ( 'T
-                  NEW-DEFINITION ) ) )
-            ( 'T
-              `((LAMBDA (,CURRENT-BINDING) ,NEW-DEFINITION) ',OLD-DEF)))
-            )
-      (SETF NEW-DEFINITION (COERCE NEW-DEFINITION 'FUNCTION))
-      (SETF (symbol-function CURRENT-BINDING) NEW-DEFINITION)
-      (push (LIST CURRENT-BINDING NEW-DEFINITION OLD-DEF) *embedded-functions*)
-      (RETURN CURRENT-BINDING) ) )
-
-(defun UNEMBED (CURRENT-BINDING)
-    (let
-      (TMP E-LIST E-HEAD CUR-DEF)
-      (SETQ E-LIST *embedded-functions*)
-      (SETQ CUR-DEF (symbol-function CURRENT-BINDING))
-      (tagbody
-       LP (if (NOT (consp E-LIST))
-              (return-from UNEMBED NIL))
-          (setf E-HEAD (car E-LIST))
-          (if (or (NOT (consp E-HEAD))
-                  (NOT (consp (cdr E-HEAD)))
-                  (NOT (EQ CURRENT-BINDING (car E-HEAD)))
-                  (NOT (EQ CUR-DEF (nth 1 E-HEAD))))
-              (progn
-                  (setf TMP E-LIST)
-                  (setf E-LIST (cdr E-LIST))
-                  (GO LP) ))
-          (setf (symbol-function CURRENT-BINDING) (nth 2 E-HEAD))
-          (if TMP
-              (setf (cdr TMP) (QCDR E-LIST))
-              (setf *embedded-functions* (QCDR E-LIST)))
-              (return-from UNEMBED CURRENT-BINDING))))
-
-(defun FLAT-BV-LIST (BV-LIST)
-  (PROG (TMP1)
-      (RETURN
-        (COND
-          ( (VARP BV-LIST)
-            (LIST BV-LIST) )
-          ( (REFVECP BV-LIST)
-	    (BREAK))
-          ( (NOT (consp BV-LIST))
-            NIL )
-          ( (EQ '= (SETQ TMP1 (QCAR BV-LIST)))
-            (FLAT-BV-LIST (QCDR BV-LIST)) )
-          ( (VARP TMP1)
-            (CONS TMP1 (FLAT-BV-LIST (QCDR BV-LIST))) )
-          ( (AND (NOT (consp TMP1)) (NOT (REFVECP TMP1)))
-            (FLAT-BV-LIST (QCDR BV-LIST)) )
-          ( 'T
-            (NCONC (FLAT-BV-LIST TMP1) (FLAT-BV-LIST (QCDR BV-LIST))) ) )) ))
-
-(defun VARP (TEST-ITEM)
-    (COND
-      ( (IDENTP TEST-ITEM)
-        TEST-ITEM )
-      ( (AND
-          (consp TEST-ITEM)
-          (OR (EQ (QCAR TEST-ITEM) 'FLUID) (EQ (QCAR TEST-ITEM) 'LEX))
-          (consp (QCDR TEST-ITEM))
-          (IDENTP (QCADR TEST-ITEM)))
-        TEST-ITEM )
-      ( 'T
-        NIL ) ) )
-
 ; 48.0 Miscellaneous CMS Interactions
 
 (defun CurrentTime ()
@@ -736,7 +662,7 @@
 (defun get_read_placeholder() *read-place-holder*)
 (defun VMREAD (st &optional (eofval *read-place-holder*))
   (read st nil eofval))
-(defun |read-line| (st &optional (eofval *read-place-holder*))
+(defun |read_line| (st &optional (eofval *read-place-holder*))
   (read-line st nil eofval))
 
 #+(OR IBCL KCL)
@@ -829,15 +755,15 @@
 (defun OBEY (S)
    #-:win32 (sb-ext::process-exit-code
              (sb-ext::run-program "/bin/sh"
-                    (list "-c" S) :input t :output t))
+                    (list "-c" S) :input t :output t :error t))
    #+:win32 (sb-ext::process-exit-code
              (sb-ext::run-program (make-absolute-filename "/lib/obey.bat")
-                    (list S) :input t :output t))
+                    (list S) :input t :output t :error t))
 )
 
 #+:openmcl
 (defun OBEY (S)
-  (ccl::run-program "sh" (list "-c" S)))
+  (ccl::run-program "sh" (list "-c" S) :input t :output t :error t))
 
 #+(and :clisp (or :win32 :unix))
 (defun OBEY (S)
