@@ -19,28 +19,59 @@
            ,s))
 
 (defmacro QAREF2O(m i j oi oj)
-    `(QAREF1O (QAREF1O ,m ,i ,oi) ,j ,oj))
+    `(aref (the (simple-array T (* *)) ,m)
+           (|sub_SI| ,i ,oi)
+           (|sub_SI| ,j ,oj)))
 
 (defmacro QSETAREF2O (m i j r oi oj)
-    `(QSETAREF1O (QAREF1O ,m ,i ,oi) ,j ,r ,oj))
-
+    `(setf (aref (the (simple-array T (* *)) ,m)
+                 (|sub_SI| ,i ,oi)
+                 (|sub_SI| ,j ,oj))
+           ,r))
 
 ;;; array creation
 
 (defun MAKEARR1 (size init)
     (make-array size :initial-element init))
 
+
+(defun MAKE_MATRIX (size1 size2)
+    (make-array (list size1 size2)))
+
+(defun MAKE_MATRIX1 (size1 size2 init)
+    (make-array (list size1 size2) :initial-element init))
+
+;;; array dimensions
+
+(defmacro ANROWS (v)
+    `(array-dimension (the (simple-array T (* *)) ,v) 0))
+
+(defmacro ANCOLS (v)
+    `(array-dimension (the (simple-array T (* *)) ,v) 1))
+
 ;;; string accessors
 
 (defmacro STR_ELT(s i)
     `(char-code (char (the string ,s) (the fixnum ,i))))
 
+(defmacro STR_SETELT(s i c)
+    (if (integerp c)
+        `(progn
+             (setf (char (the string ,s) (the fixnum ,i))
+                   (code-char (the fixnum ,c)))
+             ,c)
+        (let ((sc (gensym)))
+         `(let ((,sc ,c))
+             (setf (char (the string ,s) (the fixnum ,i))
+                   (code-char (the fixnum ,sc)))
+             ,sc))))
+
 (defmacro STR_ELT1(s i)
     `(char-code (char (the string ,s) (the fixnum (- (the fixnum ,i) 1)))))
 
 (defmacro STR_SETELT1(s i c)
     (if (integerp c)
-        `(progn 
+        `(progn
              (setf (char (the string ,s) (the fixnum (- (the fixnum ,i) 1)))
                    (code-char (the fixnum ,c)))
              ,c)
@@ -201,13 +232,13 @@
 
 ;;; Floating point macros
 
-;; Closure CL has buggy floating point optimizer, so for it we need
-;; to omit type declarations to disable optimization
-#-:openmcl
+;; Before version 1.8 Closure CL had buggy floating point optimizer, so
+;; for it we need to omit type declarations to disable optimization
+#-(and :openmcl (not :CCL-1.8))
 (defmacro DEF_DF_BINOP (name op)
    `(defmacro ,name (x y) `(the double-float (,',op (the double-float ,x)
                                                     (the double-float ,y)))))
-#+:openmcl
+#+(and :openmcl (not :CCL-1.8))
 (defmacro DEF_DF_BINOP (name op) `(defmacro ,name (x y) `(,',op ,x ,y)))
 
 (DEF_DF_BINOP |add_DF| +)
@@ -217,7 +248,10 @@
 (DEF_DF_BINOP |sub_DF| -)
 (DEF_DF_BINOP |div_DF| /)
 
-#-:openmcl
+(defmacro |abs_DF| (x) `(FLOAT-SIGN (the (double-float 1.0d0 1.0d0) 1.0d0)
+                                    (the double-float ,x)))
+
+#-(and :openmcl (not :CCL-1.8))
 (progn
 (defmacro |less_DF| (x y) `(< (the double-float ,x)
                                              (the double-float ,y)))
@@ -244,7 +278,7 @@
     `(defmacro ,name (x) `(the double-float (,',op (the double-float ,x)))))
 )
 
-#+:openmcl
+#+(and :openmcl (not :CCL-1.8))
 (progn
 (defmacro |less_DF| (x y) `(<  ,x ,y))
 (defmacro |eql_DF| (x y) `(EQL ,x ,y))
@@ -446,12 +480,12 @@
          (array-dimension (the (simple-array double-float (* *)) ,v) 1) 2))
 
 
-(defstruct (SPAD-KERNEL 
+(defstruct (SPAD-KERNEL
           (:print-function
                (lambda (p s k)
-                   (format s "#S~S" (list 
+                   (format s "#S~S" (list
                         'SPAD-KERNEL
-                         :OP (SPAD-KERNEL-OP p) 
+                         :OP (SPAD-KERNEL-OP p)
                          :ARG (SPAD-KERNEL-ARG p)
                          :NEST (SPAD-KERNEL-NEST p))))))
            OP ARG NEST (POSIT 0))
@@ -474,6 +508,10 @@
 
 ; Misc operations
 
+(defmacro |qset_first|(l x) `(SETF (CAR ,l) ,x))
+
+(defmacro |qset_rest|(l x) `(SETF (CDR ,l) ,x))
+
 (defmacro setelt (vec ind val) `(setf (elt ,vec ,ind) ,val))
 
 (defmacro pairp (x) `(consp ,x))
@@ -546,6 +584,44 @@
 
 ; macros needed for Spad:
 
+(defun TranslateTypeSymbol (ts typeOrValue)
+  (let ((typDecl (assoc (car (cdr ts))
+          '(((|Void|) (null nil))
+            ((|SingleInteger|) (fixnum 0))
+            ((|String|) (string ""))
+            ((|Boolean|) (BOOLEAN nil))
+            ((|DoubleFloat|) (DOUBLE-FLOAT 0.0d0)))
+            :test #'equal
+            )))
+  (if typDecl (setf typDecl (car (cdr typDecl)))
+              (return-from TranslateTypeSymbol (list (car ts))))
+  (cons (car ts) (if typeOrValue (cdr typDecl) (car typDecl)))))
+
+(defun GetLispType (ts)
+  (TranslateTypeSymbol ts nil))
+
+(defun GetLispValue (ts)
+  (TranslateTypeSymbol ts 't))
+
+(defun MakeDeclarations (typSyms)
+  (let* ((tranTypSyms (mapcar #'GetLispType typSyms))
+         (lispTypSyms (remove-if-not #'cdr tranTypSyms)))
+    (mapcar #'(lambda (ts) `(declare (type ,(cdr ts) ,(car ts)))) lispTypSyms)))
+
+(defun MakeInitialValues (typSyms)
+  (let ((initVals (mapcar #'GetLispValue typSyms)))
+    (mapcar #'(lambda (v) (if (endp (cdr v)) (car v) v)) initVals)))
+
+(defmacro SDEFUN (name args body)
+  (let ((vars (mapcar #'car args))
+        (decls (MakeDeclarations (butlast args))))
+        `(defun ,name ,vars ,@decls ,body)))
+
+(defmacro SPROG (vars &rest statements)
+  (let ((names (MakeInitialValues vars))
+        (decls (MakeDeclarations vars)))
+    `(block nil (let ,names ,@decls ,@statements))))
+
 (defmacro EXIT (&rest value) `(return-from SEQ ,@value))
 
 (defmacro SEQ (&rest form)
@@ -587,18 +663,18 @@
 
 (defmacro SPADCALL (&rest L)
   (let ((args (butlast l))
-	(fn (car (last l)))
-	(gi (gensym)))
+        (fn (car (last l)))
+        (gi (gensym)))
      ;; (values t) indicates a single return value
     `(let ((,gi ,fn))
        (the (values t)
-	 (funcall
-          (the #-(or :genera :lispworks)
+         (funcall
+          (the #-(or :GCL :genera :lispworks)
                    (function ,(make-list (length l) :initial-element t) t)
-               #+(or :genera :lispworks)function
-	    (car ,gi))
-	  ,@args
-	  (cdr ,gi))))))
+               #+(or :GCL :genera :lispworks)function
+            (car ,gi))
+          ,@args
+          (cdr ,gi))))))
 
 (defmacro SPADMAP(&rest args) `'(SPADMAP ,@args))
 
@@ -643,9 +719,14 @@
 (defmacro |check_subtype| (pred submode val)
    `(|assert| ,pred (coerce-failure-msg ,val ,submode)))
 
+(defmacro |check_subtype2| (pred submode mode val)
+   `(|assert| ,pred (|coerce_failure_msg| ,val ,submode ,mode)))
+
 (defmacro |check_union| (pred branch val)
    `(|assert| ,pred (coerce-failure-msg ,val ,branch )))
 
+(defmacro |check_union2| (pred branch umode val)
+   `(|assert| ,pred (|check_union_failure_msg| ,val ,branch ,umode)))
 
 ;;; Needed by interpreter
 (defmacro REPEAT (&rest L) (|expandREPEAT| L))
